==> vtk-8.0.1-3-armv6h.pkg.tar.xz: vtk/vtkUnstructuredGrid.java <==
// java wrapper for vtkUnstructuredGrid object
//

package vtk;
import vtk.*;

public class vtkUnstructuredGrid extends vtkUnstructuredGridBase
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetDataObjectType_2();
  public int GetDataObjectType()
    { return GetDataObjectType_2(); }

  private native void Allocate_3(int id0,int id1);
  public void Allocate(int id0,int id1)
    { Allocate_3(id0,id1); }

  private native int InsertNextCell_4(int id0,vtkIdList id1);
  public int InsertNextCell(int id0,vtkIdList id1)
    { return InsertNextCell_4(id0,id1); }

  private native void Reset_5();
  public void Reset()
    { Reset_5(); }

  private native void CopyStructure_6(vtkDataSet id0);
  public void CopyStructure(vtkDataSet id0)
    { CopyStructure_6(id0); }

  private native int GetNumberOfCells_7();
  public int GetNumberOfCells()
    { return GetNumberOfCells_7(); }

  private native long GetCell_8(int id0);
  public vtkCell GetCell(int id0) {
    long temp = GetCell_8(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetCell_9(int id0,vtkGenericCell id1);
  public void GetCell(int id0,vtkGenericCell id1)
    { GetCell_9(id0,id1); }

  private native void GetCellBounds_10(int id0,double id1[]);
  public void GetCellBounds(int id0,double id1[])
    { GetCellBounds_10(id0,id1); }

  private native void GetCellPoints_11(int id0,vtkIdList id1);
  public void GetCellPoints(int id0,vtkIdList id1)
    { GetCellPoints_11(id0,id1); }

  private native void GetPointCells_12(int id0,vtkIdList id1);
  public void GetPointCells(int id0,vtkIdList id1)
    { GetPointCells_12(id0,id1); }

  private native long NewCellIterator_13();
  public vtkCellIterator NewCellIterator() {
    long temp = NewCellIterator_13();

    if (temp == 0) return null;
    return (vtkCellIterator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetCellType_14(int id0);
  public int GetCellType(int id0)
    { return GetCellType_14(id0); }

  private native long GetCellTypesArray_15();
  public vtkUnsignedCharArray GetCellTypesArray() {
    long temp = GetCellTypesArray_15();

    if (temp == 0) return null;
    return (vtkUnsignedCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetCellLocationsArray_16();
  public vtkIdTypeArray GetCellLocationsArray() {
    long temp = GetCellLocationsArray_16();

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Squeeze_17();
  public void Squeeze()
    { Squeeze_17(); }

  private native void Initialize_18();
  public void Initialize()
    { Initialize_18(); }

  private native int GetMaxCellSize_19();
  public int GetMaxCellSize()
    { return GetMaxCellSize_19(); }

  private native void BuildLinks_20();
  public void BuildLinks()
    { BuildLinks_20(); }

  private native long GetCellLinks_21();
  public vtkCellLinks GetCellLinks() {
    long temp = GetCellLinks_21();

    if (temp == 0) return null;
    return (vtkCellLinks)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetFaceStream_22(int id0,vtkIdList id1);
  public void GetFaceStream(int id0,vtkIdList id1)
    { GetFaceStream_22(id0,id1); }

  private native void SetCells_23(int id0,vtkCellArray id1);
  public void SetCells(int id0,vtkCellArray id1)
    { SetCells_23(id0,id1); }

  private native void SetCells_24(vtkUnsignedCharArray id0,vtkIdTypeArray id1,vtkCellArray id2);
  public void SetCells(vtkUnsignedCharArray id0,vtkIdTypeArray id1,vtkCellArray id2)
    { SetCells_24(id0,id1,id2); }

  private native void SetCells_25(vtkUnsignedCharArray id0,vtkIdTypeArray id1,vtkCellArray id2,vtkIdTypeArray id3,vtkIdTypeArray id4);
  public void SetCells(vtkUnsignedCharArray id0,vtkIdTypeArray id1,vtkCellArray id2,vtkIdTypeArray id3,vtkIdTypeArray id4)
    { SetCells_25(id0,id1,id2,id3,id4); }

  private native long GetCells_26();
  public vtkCellArray GetCells() {
    long temp = GetCells_26();

    if (temp == 0) return null;
    return (vtkCellArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void RemoveReferenceToCell_27(int id0,int id1);
  public void RemoveReferenceToCell(int id0,int id1)
    { RemoveReferenceToCell_27(id0,id1); }

  private native void AddReferenceToCell_28(int id0,int id1);
  public void AddReferenceToCell(int id0,int id1)
    { AddReferenceToCell_28(id0,id1); }

  private native void ResizeCellList_29(int id0,int id1);
  public void ResizeCellList(int id0,int id1)
    { ResizeCellList_29(id0,id1); }

  private native void GetCellNeighbors_30(int id0,vtkIdList id1,vtkIdList id2);
  public void GetCellNeighbors(int id0,vtkIdList id1,vtkIdList id2)
    { GetCellNeighbors_30(id0,id1,id2); }

  private native int GetPiece_31();
  public int GetPiece()
    { return GetPiece_31(); }

  private native int GetNumberOfPieces_32();
  public int GetNumberOfPieces()
    { return GetNumberOfPieces_32(); }

  private native int GetGhostLevel_33();
  public int GetGhostLevel()
    { return GetGhostLevel_33(); }

  private native int GetActualMemorySize_34();
  public int GetActualMemorySize()
    { return GetActualMemorySize_34(); }

  private native void ShallowCopy_35(vtkDataObject id0);
  public void ShallowCopy(vtkDataObject id0)
    { ShallowCopy_35(id0); }

  private native void DeepCopy_36(vtkDataObject id0);
  public void DeepCopy(vtkDataObject id0)
    { DeepCopy_36(id0); }

  private native void GetIdsOfCellsOfType_37(int id0,vtkIdTypeArray id1);
  public void GetIdsOfCellsOfType(int id0,vtkIdTypeArray id1)
    { GetIdsOfCellsOfType_37(id0,id1); }

  private native int IsHomogeneous_38();
  public int IsHomogeneous()
    { return IsHomogeneous_38(); }

  private native void RemoveGhostCells_39();
  public void RemoveGhostCells()
    { RemoveGhostCells_39(); }

  private native long GetData_40(vtkInformation id0);
  public vtkUnstructuredGrid GetData(vtkInformation id0) {
    long temp = GetData_40(id0);

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetData_41(vtkInformationVector id0,int id1);
  public vtkUnstructuredGrid GetData(vtkInformationVector id0,int id1) {
    long temp = GetData_41(id0,id1);

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetFaces_42();
  public vtkIdTypeArray GetFaces() {
    long temp = GetFaces_42();

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetFaceLocations_43();
  public vtkIdTypeArray GetFaceLocations() {
    long temp = GetFaceLocations_43();

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int InitializeFacesRepresentation_44(int id0);
  public int InitializeFacesRepresentation(int id0)
    { return InitializeFacesRepresentation_44(id0); }

  private native long GetCell_45(int id0,int id1,int id2);
  public vtkCell GetCell(int id0,int id1,int id2) {
    long temp = GetCell_45(id0,id1,id2);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkUnstructuredGrid() { super(); }

  public vtkUnstructuredGrid(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.1.0-6-armv6h.pkg.tar.xz: vtk/vtkUnstructuredGrid.java <==
// java wrapper for vtkUnstructuredGrid object
//

package vtk;
import vtk.*;

public class vtkUnstructuredGrid extends vtkUnstructuredGridBase
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetDataObjectType_2();
  public int GetDataObjectType()
    { return GetDataObjectType_2(); }

  private native void Allocate_3(int id0,int id1);
  public void Allocate(int id0,int id1)
    { Allocate_3(id0,id1); }

  private native int InsertNextCell_4(int id0,vtkIdList id1);
  public int InsertNextCell(int id0,vtkIdList id1)
    { return InsertNextCell_4(id0,id1); }

  private native void Reset_5();
  public void Reset()
    { Reset_5(); }

  private native void CopyStructure_6(vtkDataSet id0);
  public void CopyStructure(vtkDataSet id0)
    { CopyStructure_6(id0); }

  private native int GetNumberOfCells_7();
  public int GetNumberOfCells()
    { return GetNumberOfCells_7(); }

  private native long GetCell_8(int id0);
  public vtkCell GetCell(int id0) {
    long temp = GetCell_8(id0);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetCell_9(int id0,vtkGenericCell id1);
  public void GetCell(int id0,vtkGenericCell id1)
    { GetCell_9(id0,id1); }

  private native void GetCellBounds_10(int id0,double id1[]);
  public void GetCellBounds(int id0,double id1[])
    { GetCellBounds_10(id0,id1); }

  private native void GetCellPoints_11(int id0,vtkIdList id1);
  public void GetCellPoints(int id0,vtkIdList id1)
    { GetCellPoints_11(id0,id1); }

  private native void GetPointCells_12(int id0,vtkIdList id1);
  public void GetPointCells(int id0,vtkIdList id1)
    { GetPointCells_12(id0,id1); }

  private native long NewCellIterator_13();
  public vtkCellIterator NewCellIterator() {
    long temp = NewCellIterator_13();

    if (temp == 0) return null;
    return (vtkCellIterator)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetCellType_14(int id0);
  public int GetCellType(int id0)
    { return GetCellType_14(id0); }

  private native long GetCellTypesArray_15();
  public vtkUnsignedCharArray GetCellTypesArray() {
    long temp = GetCellTypesArray_15();

    if (temp == 0) return null;
    return (vtkUnsignedCharArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetCellLocationsArray_16();
  public vtkIdTypeArray GetCellLocationsArray() {
    long temp = GetCellLocationsArray_16();

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void Squeeze_17();
  public void Squeeze()
    { Squeeze_17(); }

  private native void Initialize_18();
  public void Initialize()
    { Initialize_18(); }

  private native int GetMaxCellSize_19();
  public int GetMaxCellSize()
    { return GetMaxCellSize_19(); }

  private native void BuildLinks_20();
  public void BuildLinks()
    { BuildLinks_20(); }

  private native long GetCellLinks_21();
  public vtkCellLinks GetCellLinks() {
    long temp = GetCellLinks_21();

    if (temp == 0) return null;
    return (vtkCellLinks)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void GetFaceStream_22(int id0,vtkIdList id1);
  public void GetFaceStream(int id0,vtkIdList id1)
    { GetFaceStream_22(id0,id1); }

  private native void SetCells_23(int id0,vtkCellArray id1);
  public void SetCells(int id0,vtkCellArray id1)
    { SetCells_23(id0,id1); }

  private native void SetCells_24(vtkUnsignedCharArray id0,vtkIdTypeArray id1,vtkCellArray id2);
  public void SetCells(vtkUnsignedCharArray id0,vtkIdTypeArray id1,vtkCellArray id2)
    { SetCells_24(id0,id1,id2); }

  private native void SetCells_25(vtkUnsignedCharArray id0,vtkIdTypeArray id1,vtkCellArray id2,vtkIdTypeArray id3,vtkIdTypeArray id4);
  public void SetCells(vtkUnsignedCharArray id0,vtkIdTypeArray id1,vtkCellArray id2,vtkIdTypeArray id3,vtkIdTypeArray id4)
    { SetCells_25(id0,id1,id2,id3,id4); }

  private native long GetCells_26();
  public vtkCellArray GetCells() {
    long temp = GetCells_26();

    if (temp == 0) return null;
    return (vtkCellArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void RemoveReferenceToCell_27(int id0,int id1);
  public void RemoveReferenceToCell(int id0,int id1)
    { RemoveReferenceToCell_27(id0,id1); }

  private native void AddReferenceToCell_28(int id0,int id1);
  public void AddReferenceToCell(int id0,int id1)
    { AddReferenceToCell_28(id0,id1); }

  private native void ResizeCellList_29(int id0,int id1);
  public void ResizeCellList(int id0,int id1)
    { ResizeCellList_29(id0,id1); }

  private native void GetCellNeighbors_30(int id0,vtkIdList id1,vtkIdList id2);
  public void GetCellNeighbors(int id0,vtkIdList id1,vtkIdList id2)
    { GetCellNeighbors_30(id0,id1,id2); }

  private native int GetPiece_31();
  public int GetPiece()
    { return GetPiece_31(); }

  private native int GetNumberOfPieces_32();
  public int GetNumberOfPieces()
    { return GetNumberOfPieces_32(); }

  private native int GetGhostLevel_33();
  public int GetGhostLevel()
    { return GetGhostLevel_33(); }

  private native int GetActualMemorySize_34();
  public int GetActualMemorySize()
    { return GetActualMemorySize_34(); }

  private native void ShallowCopy_35(vtkDataObject id0);
  public void ShallowCopy(vtkDataObject id0)
    { ShallowCopy_35(id0); }

  private native void DeepCopy_36(vtkDataObject id0);
  public void DeepCopy(vtkDataObject id0)
    { DeepCopy_36(id0); }

  private native void GetIdsOfCellsOfType_37(int id0,vtkIdTypeArray id1);
  public void GetIdsOfCellsOfType(int id0,vtkIdTypeArray id1)
    { GetIdsOfCellsOfType_37(id0,id1); }

  private native int IsHomogeneous_38();
  public int IsHomogeneous()
    { return IsHomogeneous_38(); }

  private native void RemoveGhostCells_39();
  public void RemoveGhostCells()
    { RemoveGhostCells_39(); }

  private native long GetData_40(vtkInformation id0);
  public vtkUnstructuredGrid GetData(vtkInformation id0) {
    long temp = GetData_40(id0);

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetData_41(vtkInformationVector id0,int id1);
  public vtkUnstructuredGrid GetData(vtkInformationVector id0,int id1) {
    long temp = GetData_41(id0,id1);

    if (temp == 0) return null;
    return (vtkUnstructuredGrid)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetFaces_42();
  public vtkIdTypeArray GetFaces() {
    long temp = GetFaces_42();

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetFaceLocations_43();
  public vtkIdTypeArray GetFaceLocations() {
    long temp = GetFaceLocations_43();

    if (temp == 0) return null;
    return (vtkIdTypeArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int InitializeFacesRepresentation_44(int id0);
  public int InitializeFacesRepresentation(int id0)
    { return InitializeFacesRepresentation_44(id0); }

  private native int GetMeshMTime_45();
  public int GetMeshMTime()
    { return GetMeshMTime_45(); }

  private native long GetCell_46(int id0,int id1,int id2);
  public vtkCell GetCell(int id0,int id1,int id2) {
    long temp = GetCell_46(id0,id1,id2);

    if (temp == 0) return null;
    return (vtkCell)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkUnstructuredGrid() { super(); }

  public vtkUnstructuredGrid(long id) { super(id); }
  public native long   VTKInit();

}
